@@ -18,6 +18,7 @@ GtkWidget *window;
 GtkWidget *main_vbox;
 GtkWidget *notebook;
 GtkWidget **sheets;
+GtkWidget **scrolled_windows;
 GtkWidget *show_hide_box;
 GtkWidget *status_box;
 GtkWidget *location;
@@ -34,6 +35,8 @@ GtkWidget *left_button;
 GtkWidget *center_button;
 GtkWidget *right_button;
 GtkWidget *tpixmap;
+GtkWidget *bullet[10];
+GtkWidget *curve;
 
 
 void
@@ -322,24 +325,30 @@ void alarm_deactivate(GtkWidget *widget, gint row, gint col, gpointer data)
 {
  printf("DEACTIVATE CELL: %d %d\n",row,col);
 }
-gint alarm_traverse(GtkWidget *widget, gint row, gint col, gint new_row, gint new_col,
+gint alarm_traverse(GtkWidget *widget, gint row, gint col, gint *new_row, gint *new_col,
 gpointer data)
 {
- printf("TRAVERSE: %d %d %d %d\n",row,col,new_row,new_col);
+ printf("TRAVERSE: %d %d %d %d\n",row,col,*new_row,*new_col);
  return TRUE;
 }
 
+void show_child(GtkWidget *widget, gpointer data)
+{
+ if(!GTK_WIDGET_MAPPED(curve))
+         gtk_sheet_put(GTK_SHEET(sheets[0]), curve, 550, 120);
+
+}
 void
 build_example1(GtkWidget *widget)
 {
  GtkSheet *sheet;
+ GtkWidget *show_button;
  GtkSheetRange range;
+ GdkRectangle area;
  GdkColor color;
  GdkFont *font;
  gchar font_name1[]="-bitstream-charter-bold-r-normal--36-360-72-72-p-0-iso8859-1";
  gchar font_name2[]="-bitstream-charter-bold-r-normal--28-280-72-72-p-0-iso8859-1";
- gchar font_name3[]="-bitstream-charter-bold-r-normal--20-200-72-72-p-0-iso8859-1";
- gchar font_name4[]="-bitstream-charter-bold-r-normal--20-200-72-72-p-0-iso8859-1";
 
  gchar name[10];
  gint i;
@@ -385,8 +394,7 @@ build_example1(GtkWidget *widget)
  gdk_color_alloc(gtk_widget_get_colormap(widget), &color);
  gtk_sheet_range_set_foreground(sheet, range, &color);
 
- gtk_sheet_set_cell(sheet, 2,2, GTK_JUSTIFY_CENTER,
-                    "GtkSheet");
+ gtk_sheet_set_cell(sheet, 2,2, GTK_JUSTIFY_CENTER, "GtkSheet");
 
  range.row0=3;
  range.rowi=3;
@@ -399,43 +407,23 @@ build_example1(GtkWidget *widget)
  gdk_color_alloc(gtk_widget_get_colormap(widget), &color);
  gtk_sheet_range_set_foreground(sheet, range, &color);
 
- font=gdk_font_load(font_name3);
- if(!font)
-   g_warning ("Couldn't load %s", font_name3);
- else
-   gtk_sheet_range_set_font(sheet, range, font);
- 
  gtk_sheet_set_cell(sheet,3,2,GTK_JUSTIFY_CENTER,
-      "a Matrix widget for Gtk+");
+"a Matrix widget for Gtk+");
 
- range.row0=4;
- range.rowi=11;
- range.col0=0;
- range.coli=10;
-
- font=gdk_font_load(font_name4);
- if(!font)
-   g_warning ("Couldn't load %s", font_name4);
- else
-   gtk_sheet_range_set_font(sheet, range, font);
-
- gtk_sheet_set_cell(sheet,4,0,GTK_JUSTIFY_LEFT,
+ gtk_sheet_set_cell(sheet,4,1,GTK_JUSTIFY_LEFT,
 "GtkSheet is a matrix where you can allocate cells of text.");
- gtk_sheet_set_cell(sheet,5,0,GTK_JUSTIFY_LEFT,
+ gtk_sheet_set_cell(sheet,5,1,GTK_JUSTIFY_LEFT,
 "Cell contents can be edited interactively with an specially designed entry");
- gtk_sheet_set_cell(sheet,6,0,GTK_JUSTIFY_LEFT,
-"You can change width, height, background color, foreground color, border");
- gtk_sheet_set_cell(sheet,7,0,GTK_JUSTIFY_LEFT,
-"color, border style, and many other attributes.");
- gtk_sheet_set_cell(sheet, 8,0, GTK_JUSTIFY_LEFT,
-                    "You can drag & drop the selection");
- gtk_sheet_set_cell(sheet, 9,0, GTK_JUSTIFY_LEFT,
-                    "and resize it clicking the right-bottom corner");
- gtk_sheet_set_cell(sheet, 10,0, GTK_JUSTIFY_LEFT,
-                    "Store the selection on the clipboard pressing Ctrl-C");
- gtk_sheet_set_cell(sheet, 11,0, GTK_JUSTIFY_LEFT,
-                    "(The selection handler has not been implemented yet)");
-
+ gtk_sheet_set_cell(sheet,6,1,GTK_JUSTIFY_LEFT,
+"You can change colors, borders, and many other attributes");
+ gtk_sheet_set_cell(sheet, 7,1, GTK_JUSTIFY_LEFT,
+"Drag & drop or resize the selection clicking the corner or border");
+ gtk_sheet_set_cell(sheet, 8, 1, GTK_JUSTIFY_LEFT,
+"Store the selection on the clipboard pressing Ctrl-C");
+ gtk_sheet_set_cell(sheet, 9, 1, GTK_JUSTIFY_LEFT,
+ "(The selection handler has not been implemented yet)");
+ gtk_sheet_set_cell(sheet, 10, 1, GTK_JUSTIFY_LEFT,
+ "You can add buttons, charts, pixmaps, and other widgets");
 
 
  gtk_signal_connect(GTK_OBJECT(sheet),
@@ -458,11 +446,11 @@ build_example1(GtkWidget *widget)
                     (GtkSignalFunc) alarm_change, 
                     NULL);
  gtk_signal_connect(GTK_OBJECT(sheet),
-                    "activate_cell",
+                    "activate",
                     (GtkSignalFunc) alarm_activate, 
                     NULL);
  gtk_signal_connect(GTK_OBJECT(sheet),
-                    "deactivate_cell",
+                    "deactivate",
                     (GtkSignalFunc) alarm_deactivate, 
                     NULL);
 */
@@ -471,9 +459,38 @@ build_example1(GtkWidget *widget)
                     (GtkSignalFunc) alarm_traverse, 
                     NULL);
 
-/*
- gtk_sheet_change_entry(sheet, gtk_combo_get_type()); 
-*/
+ curve=gtk_curve_new();
+ gtk_curve_set_range(GTK_CURVE(curve), 0, 200, 0, 200);
+ gtk_widget_show(curve);
+
+ pixmap=gdk_pixmap_create_from_xpm(window->window, &mask,
+				   &window->style->bg[GTK_STATE_NORMAL],
+ 				   "bullet.xpm");
+
+ for(i=0; i<5; i++){
+      bullet[i] = gtk_pixmap_new(pixmap, mask);
+      gtk_widget_show(bullet[i]);
+      gtk_sheet_get_cell_info(GTK_SHEET(sheets[0]), 4+i, 0, &area);
+      gtk_sheet_put(GTK_SHEET(sheets[0]), bullet[i], 
+                    area.x+area.width/2-8, area.y+area.height/2-8);
+ }
+
+ bullet[5] = gtk_pixmap_new(pixmap, mask);
+ gtk_widget_show(bullet[5]);
+ gtk_sheet_get_cell_info(GTK_SHEET(sheets[0]), 10, 0, &area);
+ gtk_sheet_put(GTK_SHEET(sheets[0]), bullet[i], 
+               area.x+area.width/2-8, area.y+area.height/2-8);
+
+ show_button=gtk_button_new_with_label("Show me a plot");
+ gtk_widget_show(show_button);
+ gtk_widget_set_usize(show_button, 100,60);
+ gtk_sheet_get_cell_info(GTK_SHEET(sheets[0]), 12, 2, &area);
+ gtk_sheet_put(GTK_SHEET(sheets[0]), show_button, area.x, area.y);
+
+ gtk_signal_connect(GTK_OBJECT(show_button), "clicked",
+                    (GtkSignalFunc) show_child, 
+                    NULL);
+
 }
 
 
@@ -516,8 +533,9 @@ build_example2(GtkWidget *widget)
  gtk_sheet_set_cell(sheet, 2,2, GTK_JUSTIFY_CENTER,
                     "(Try typing numbers)");
  gtk_sheet_set_active_cell(sheet, 3, 0);
-
+/*
  gtk_sheet_set_update_policy(sheet, GTK_UPDATE_CONTINUOUS, GTK_UPDATE_CONTINUOUS);
+*/
  gtk_signal_connect(GTK_OBJECT(sheet),
                     "button_press_event",
                     (GtkSignalFunc) do_popup, 
@@ -606,10 +624,12 @@ show_sheet_entry(GtkWidget *widget, gpointer data)
  char *text;
  GtkSheet *sheet;
  GtkEntry *sheet_entry;
+ gint cur_page;
 
  if(!GTK_WIDGET_HAS_FOCUS(widget)) return;
 
- sheet = GTK_SHEET(GTK_NOTEBOOK(notebook)->cur_page->child);
+ cur_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
+ sheet=GTK_SHEET(sheets[cur_page]);
  sheet_entry = GTK_ENTRY(gtk_sheet_get_entry(sheet));
 
  if((text=gtk_entry_get_text (GTK_ENTRY(entry)))){
@@ -622,11 +642,11 @@ activate_sheet_entry(GtkWidget *widget, gpointer data)
 {
   GtkSheet *sheet;
   GtkEntry *sheet_entry;
-  gint row, col;
+  gint cur_page, row, col;
   gint justification=GTK_JUSTIFY_LEFT;
   
-
-  sheet=GTK_SHEET(GTK_NOTEBOOK(notebook)->cur_page->child);
+  cur_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
+  sheet=GTK_SHEET(sheets[cur_page]);
   row=sheet->active_cell.row; col=sheet->active_cell.col;
 
   sheet_entry = GTK_ENTRY(gtk_sheet_get_entry(sheet));
@@ -646,10 +666,12 @@ show_entry(GtkWidget *widget, gpointer data)
  char *text; 
  GtkSheet *sheet;
  GtkWidget * sheet_entry;
+ gint cur_page;
 
  if(!GTK_WIDGET_HAS_FOCUS(widget)) return;
 
- sheet = GTK_SHEET(GTK_NOTEBOOK(notebook)->cur_page->child);
+ cur_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
+ sheet=GTK_SHEET(sheets[cur_page]);
  sheet_entry = gtk_sheet_get_entry(sheet);
 
  if((text=gtk_entry_get_text (GTK_ENTRY(sheet_entry))))
@@ -666,11 +688,11 @@ justify_left(GtkWidget *widget)
   cur_page=gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
   current=GTK_SHEET(sheets[cur_page]);
 
-  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(left_button),
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(left_button),
   GTK_STATE_ACTIVE);
-  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(right_button),
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(right_button),
   GTK_STATE_NORMAL);
-  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(center_button),
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(center_button),
   GTK_STATE_NORMAL);
 
   gtk_sheet_range_set_justification(current, current->range,
@@ -717,7 +739,7 @@ justify_right(GtkWidget *widget)
   GTK_JUSTIFY_RIGHT);
 }
 
-void
+gint
 activate_sheet_cell(GtkWidget *widget, gint row, gint column, gpointer data) 
 {
   GtkSheet *sheet;
@@ -763,6 +785,8 @@ activate_sheet_cell(GtkWidget *widget, gint row, gint column, gpointer data)
          justify_left(NULL);
 	 break;
   }
+
+  return TRUE;
 }
 
 void 
@@ -1004,13 +1028,13 @@ int main(int argc, char *argv[])
 
   window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title(GTK_WINDOW(window), "GtkSheet Demo");
-  gtk_widget_set_usize(GTK_WIDGET(window), 800, 500);
+  gtk_widget_set_usize(GTK_WIDGET(window), 900, 600);
 
   gtk_signal_connect (GTK_OBJECT (window), "destroy",
 		      GTK_SIGNAL_FUNC (quit), NULL);
 
   main_vbox=gtk_vbox_new(FALSE,1);
-  gtk_container_border_width(GTK_CONTAINER(main_vbox),0); 
+  gtk_container_set_border_width(GTK_CONTAINER(main_vbox),0); 
   gtk_container_add(GTK_CONTAINER(window), main_vbox);
   gtk_widget_show(main_vbox);
 
@@ -1074,8 +1098,9 @@ int main(int argc, char *argv[])
   bordercombo=gtk_border_combo_new();
   gtk_toolbar_append_widget(GTK_TOOLBAR(toolbar),
 			    bordercombo, "border", "border");
-  gtk_widget_show(bordercombo);
   gtk_widget_set_usize(GTK_COMBO_BOX(bordercombo)->button, 32, 32);
+  gtk_widget_show(bordercombo);
+
   gtk_signal_connect(GTK_OBJECT(bordercombo),
 		     "changed", (GtkSignalFunc)change_border, NULL);
 
@@ -1104,12 +1129,13 @@ int main(int argc, char *argv[])
   gtk_widget_show(toolbar);
 
   status_box=gtk_hbox_new(FALSE, 1);
-  gtk_container_border_width(GTK_CONTAINER(status_box),0);
+  gtk_container_set_border_width(GTK_CONTAINER(status_box),0);
   gtk_box_pack_start(GTK_BOX(main_vbox), status_box, FALSE, TRUE, 0);
   gtk_widget_show(status_box);
 
-  location=gtk_label_new(""); gtk_widget_size_request(location,
-  &request); gtk_widget_set_usize(location, 160, request.height);
+  location=gtk_label_new(""); 
+  gtk_widget_size_request(location, &request); 
+  gtk_widget_set_usize(location, 160, request.height);
   gtk_box_pack_start(GTK_BOX(status_box), location, FALSE, TRUE, 0);
   gtk_widget_show(location);
 
@@ -1122,18 +1148,26 @@ int main(int argc, char *argv[])
   gtk_widget_show(notebook);
 
   for(i=0; i<3; i++){
-   sheets=(GtkWidget **)realloc(sheets, sizeof(GtkWidget *));
+   sheets=(GtkWidget **)realloc(sheets, (i+1)*sizeof(GtkWidget *));
    sheets[i]=gtk_sheet_new(1000,26,title[i]);
+   scrolled_windows=(GtkWidget **)realloc(scrolled_windows, (i+1)*sizeof(GtkWidget *));
+   scrolled_windows[i]=gtk_scrolled_window_new(NULL, NULL);
+/*   GTK_SCROLLED_WINDOW(scrolled_windows[i])->shadow_type = GTK_SHADOW_IN;
+*/
+   gtk_container_add(GTK_CONTAINER(scrolled_windows[i]), sheets[i]);
 
-   gtk_widget_show_all(sheets[i]); label=gtk_label_new(folder[i]);
-   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), GTK_WIDGET(sheets[i]),
+   gtk_widget_show(sheets[i]);
+   gtk_widget_show(scrolled_windows[i]);
+
+   label=gtk_label_new(folder[i]);
+   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), GTK_WIDGET(scrolled_windows[i]),
    label);
 
    gtk_signal_connect(GTK_OBJECT(gtk_sheet_get_entry(GTK_SHEET(sheets[i]))),
 		      "changed", (GtkSignalFunc)show_entry, NULL);
 
    gtk_signal_connect(GTK_OBJECT(sheets[i]),
-		      "activate_cell", (GtkSignalFunc)activate_sheet_cell,
+		      "activate", (GtkSignalFunc)activate_sheet_cell,
 		      NULL);
 
   }
@@ -1145,15 +1179,16 @@ int main(int argc, char *argv[])
 		      "activate", (GtkSignalFunc)activate_sheet_entry,
 		      NULL);
 
+  gtk_widget_realize(window);
 
   build_example1(sheets[0]); 
   build_example2(sheets[1]);
   build_example3(sheets[2]);
 
+
   gtk_signal_connect(GTK_OBJECT(gtk_sheet_get_entry(GTK_SHEET(sheets[2]))),
 		     "changed", (GtkSignalFunc)show_entry, NULL);
 
-  gtk_widget_show(window);
 
   pixmap=gdk_pixmap_create_from_xpm(window->window, &mask,
 				    &window->style->bg[GTK_STATE_NORMAL],
@@ -1197,6 +1232,8 @@ int main(int argc, char *argv[])
 
   gtk_widget_show(fg_pixmap);
 
+  gtk_widget_show(window);
+
   gtk_main();
 
   return(0);
