@@ -97,6 +97,7 @@ enum
 
 typedef struct _GtkSheet GtkSheet;
 typedef struct _GtkSheetClass GtkSheetClass;
+typedef struct _GtkSheetChild GtkSheetChild;
 typedef struct _GtkSheetRow GtkSheetRow;
 typedef struct _GtkSheetColumn GtkSheetColumn;
 typedef struct _GtkSheetCell GtkSheetCell;
@@ -106,6 +107,13 @@ typedef struct _GtkSheetCellAttr     GtkSheetCellAttr;
 typedef struct _GtkSheetAttr     GtkSheetAttr;
 typedef struct _GtkSheetCellBorder     GtkSheetCellBorder;
 
+struct _GtkSheetChild
+{
+  GtkWidget *widget;
+  GdkWindow *window;
+  gint x,y ;
+};
+
 struct _GtkSheetButton
 {
   gint state;
@@ -201,6 +209,9 @@ struct _GtkSheet{
 
   guint16 flags;
 
+  /* sheet children */
+  GList *children;
+
   /* allocation rectangle after the container_border_width
      and the width of the shadow border */
   GdkRectangle internal_allocation;
@@ -279,10 +290,8 @@ struct _GtkSheet{
   GdkWindow *row_title_window;
 
   /*scrollbars*/
-  GtkWidget *vscrollbar;
-  GtkWidget *hscrollbar;
-  guint8 vscrollbar_policy;
-  guint8 hscrollbar_policy;
+  GtkAdjustment *hadjustment;
+  GtkAdjustment *vadjustment;
 
   /* xor GC for the verticle drag line */
   GdkGC *xor_gc;
@@ -312,6 +321,10 @@ struct _GtkSheet{
 struct _GtkSheetClass
 {
  GtkContainerClass parent_class;
+ 
+ void (*set_scroll_adjustments) (GtkSheet *sheet,
+				 GtkAdjustment *hadjustment,
+				 GtkAdjustment *vadjustment);
 
  void (*select_row) 		(GtkSheet *sheet, gint row);
 
@@ -331,12 +344,12 @@ struct _GtkSheetClass
 
  gint (*traverse)       	(GtkSheet *sheet,
                          	gint row, gint column,
-                         	gint new_row, gint new_column);
+                         	gint *new_row, gint *new_column);
 
- void (*deactivate_cell) 	(GtkSheet *sheet,
+ gint (*deactivate)	 	(GtkSheet *sheet,
 	                  	gint row, gint column);
 
- void (*activate_cell) 		(GtkSheet *sheet,
+ gint (*activate) 		(GtkSheet *sheet,
 	                	gint row, gint column);
 
  void (*set_cell) 		(GtkSheet *sheet,
@@ -345,8 +358,14 @@ struct _GtkSheetClass
  void (*changed) 		(GtkSheet *sheet,
 	          		gint row, gint column);
 
+ void (*new_column_width)       (GtkSheet *sheet,
+                                 gint col,
+                                 gint width);
+
+ void (*new_row_height)       	(GtkSheet *sheet,
+                                 gint row,
+                                 gint height);
 
- gint scrollbar_spacing;
 };
   
 guint gtk_sheet_get_type (void);
@@ -363,7 +382,13 @@ gtk_sheet_new_browser 			(int rows, int columns, gchar *title);
 GtkWidget *
 gtk_sheet_new_with_custom_entry 	(int rows, int columns, gchar *title,
                                  	GtkType entry_type);
-
+/* change scroll adjustments */
+void
+gtk_sheet_set_hadjustment		(GtkSheet *sheet,
+					 GtkAdjustment *adjustment); 
+void
+gtk_sheet_set_vadjustment		(GtkSheet *sheet,
+					 GtkAdjustment *adjustment); 
 /* Change entry */
 void
 gtk_sheet_change_entry			(GtkSheet *sheet, GtkType entry_type);
@@ -495,24 +520,16 @@ gtk_sheet_get_vadjustment 		(GtkSheet * sheet);
 GtkAdjustment *
 gtk_sheet_get_hadjustment 		(GtkSheet * sheet);
 
-/* set scrollbars policy */
-void
-gtk_sheet_set_policy (GtkSheet * sheet,
-		      GtkPolicyType vscrollbar_policy,
-		      GtkPolicyType hscrollbar_policy);
-void
-gtk_sheet_set_update_policy (GtkSheet * sheet,
-		      GtkUpdateType vscrollbar_policy,
-		      GtkUpdateType hscrollbar_policy);
-
 /* highlight the selected range and store bounds in sheet->range */
 void gtk_sheet_select_range(GtkSheet *sheet, GtkSheetRange *range); 
 
 /* obvious */
 void gtk_sheet_unselect_range		(GtkSheet *sheet, GtkSheetRange *range); 
 
-/* set active cell where the entry will be displayed */
-void
+/* set active cell where the entry will be displayed 
+ * returns FALSE if current cell can't be deactivated or
+ * requested cell can't be activated */
+gint
 gtk_sheet_set_active_cell 		(GtkSheet *sheet, 
 					gint row, gint column);
 
@@ -521,6 +538,10 @@ void
 gtk_sheet_set_cell			(GtkSheet *sheet, 
 					int row, int col, int justification,
                    			gchar *text);
+void 
+gtk_sheet_set_cell_text			(GtkSheet *sheet, 
+					int row, int col,
+                   			gchar *text);
 
 /* get cell contents */
 gchar *     
@@ -655,6 +676,16 @@ gtk_sheet_get_attributes		(GtkSheet *sheet,
 					GtkSheetCellAttr *attributes);
 
 
+void
+gtk_sheet_put 				(GtkSheet *sheet, 
+					 GtkWidget *widget, 
+					 gint x, gint y);
+
+void
+gtk_sheet_move_child 			(GtkSheet *sheet, 
+					 GtkWidget *widget, 
+					 gint x, gint y);
+
 
 #ifdef __cplusplus
 }
